Ongoing Work
============

ES
--

* Guided evolutionary strategies: Augmenting random search with surrogate gradients
* Structured evolution with compact architectures for scalable policy optimization

PSO
---

* PSO-X: A component-based framework for the automatic design of particle swarm optimization algorithms
* Incremental social learning in particle swarms
* Frankenstein’s PSO: A composite particle swarm optimization algorithm
* The fully informed particle swarm: Simpler, maybe better
* The particle swarm - explosion, stability, and convergence in a multidimensional complex space

RS
--

* Learning to guide random search
* Online convex optimization in the bandit setting: Gradient descent without a gradient

BBO
---

* Introduction to derivative-free optimization
